namespace sap.beta.odm.utilities.billingaccount;

using { sap.odm.common.cuid, 
        sap.odm.common.managed,
        sap.odm.common.CountryCode, 
} from '../../../odm/common';

using { sap.odm.businesspartner.BusinessPartner } from '@sap/odm/dist/businesspartner';

/** reference to codeLists in index.cds */
using { 
        sap.beta.odm.utilities.billingaccount.CategoryCode,
        sap.beta.odm.utilities.billingaccount.BillingAccountRelationshipCode,
        sap.beta.odm.utilities.billingaccount.ToleranceGroupCode, 
        sap.beta.odm.utilities.billingaccount.ClearingCategoryCode,
        sap.beta.odm.utilities.billingaccount.AccountDeterminationIdCode
       }
        from '.';

/* 
 * Utilities Cloud Only dedicated ACCOUNT which is connected to
 * an organization (BP: company, subsidiary) or person in which
 * your company has a business interest.
 */
entity BillingAccount : cuid { /** TrackPurpose - dpp aspect requires BP reference

    /** Human-readable identifier for Contract Account in S4H */
    displayId                     : String(12);

    /** identifier for Business Partner */
    businessPartner               : Association to one BusinessPartner;

    /** Identifier for Billing Account Category */
    category                      : CategoryCode;

    /** Relationship of Business Partner to Contract Account */
    billingAccountRelationship    : BillingAccountRelationshipCode;

    /** Key under which agreements are made for the tolerance values for payment differences */     
    toleranceGroup                : ToleranceGroupCode;

    /** contract account reference in automatic clearing postings */
    clearingCategory              : ClearingCategoryCode;

    /** Account determination ID for IS-U contract accounts */
    accountDeterminationCode      : AccountDeterminationIdCode;

     /** Rules to determine the due dates for incoming payments 
     and the deadlines for outgoing payments  */
    paymentTerms                   : String(4);

    /** Billing Account Name */
    contractAccountName            : String(35);

    /* Company Code Group to which the Billing Account belongs */
    companyCodeGroup               : String(4);

    /** Standard Company Code to which the Billing Account belongs */
    companyCode                    : String(4);

    /** Identifier for Incoming Payment Method */
    incomingPaymentMethod          : String(1);

    /** Identifier for Outgoing Payment Method */    
    outgoingPaymentMethod          : String(5);

    /** Bank Details ID for Incoming Payments */
    incomingPaymentBankAccountId   : String(4);

    /** Bank Details ID for Outgoing Payments */
    outgoingPaymentBankAccountId   : String(4);

    /** Payment Card ID for Incoming Payments */
    incomingPaymentPaymentCard     : String(6);

    /** Payment Card ID for Outgoing Payments */
    outgoingPaymentPaymentCard     : String(6);

    /** Identifier for Country/Region */
    country                        : CountryCode;

    /** Address Number for Billing Account */
    accountAddressId               : UUID;

    /** Identifier for Alternative Payee */
    alternativePayee               : Association to one BusinessPartner;

    /** Identifier for Alternative Payer */
    alternativePayer               : Association to one BusinessPartner;
    
    /** Key that defines a dunning procedure */ 
    dunningProcedure               : String(2);    

    /** Identifier for Alternative Billing Account for collective billing based on category */
    alternativeBillingAccount      : Association to  one BillingAccount;

}