namespace sap.c4u.foundation.retailer.configuration;

using {
    sap.odm.sales.CustomerOrder,
    sap.odm.sales.SalesProcessingStatusCode
} from '../odm/sales';

using { sap.c4u.foundation.retailer.configuration.CustomerOrderUtilitiesStatusMappingTypeCode } from './CustomerOrderUtilitiesStatusMappingTypeCodes';
using { sap.c4u.foundation.retailer.configuration.CustomerOrderUtilitiesStatusSourceSystem } from './CustomerOrderUtilitiesStatusSourceSystem';


/**
 * Entity for source system Order Items status mapping to
 * Foundation CustomerOrder item Processing Status Code
 */
entity CustomerOrderUtilitiesStatusMapping {
        /**
         * Specifies the source system
         */
    key sourceSystem       : CustomerOrderUtilitiesStatusSourceSystem;
        /**
         * Specifies the source system item status
         */
    key sourceSystemStatus : String(40);
        /**
         * Specifies the processing status of a sales document
         */
        processingStatus   : SalesProcessingStatusCode;
        /**
         * Specifies the type of source
         */
        type               : CustomerOrderUtilitiesStatusMappingTypeCode;
}

/**
 * View to get CustomerOrderItems processing statuses
 */
view CustomerOrderWithItems as
    select from CustomerOrder {
        id,
        items.id               as itemID,
        items.processingStatus as processingStatus
    };
