
namespace sap.odm.utilities.sales;

using {
  sap.odm.sales.CustomerOrder,
  sap.odm.sales.CustomerOrderItem,
  sap.odm.sales.CustomerOrderNote,
  sap.odm.sales.CustomerOrderPriceComponent,
  sap.odm.sales.CustomerOrderItemSalesAspect,
  sap.odm.sales.SalesOrderScheduleLine,
  sap.odm.sales.service.CustomerOrderItemServiceAspect,
  sap.odm.sales.service.ServiceOrderItemReferenceObject,
  sap.odm.sales.CustomerOrderPartner,
  sap.odm.sales.SalesDocumentAddress,
  sap.odm.sales.CustomerOrderPartnerInternalRef,
  sap.odm.sales.CustomerOrderSalesAspect,
  sap.odm.sales.service.CustomerOrderServiceAspect,
  sap.odm.sales.service.ServiceOrderReferenceObject
} from '../../odm/sales';

using {
    sap.odm.utilities.sales.CustomerOrderItemUtilitiesAspect,
    sap.odm.utilities.sales.CustomerOrderItemUtilitiesReferenceObjectAspect,
    sap.odm.utilities.sales.CustomerOrderItemUtilitiesSubsequentDocumentAspect,
    sap.odm.utilities.sales.CustomerOrderItemUtilitiesSubscriptionAspect
} from '..';

using {
  sap.odm.common.address.PersonAddressDetails
} from '../../odm/common';

/* --------------------------------------------------------------- */
/* Aspects                                                         */
/* --------------------------------------------------------------- */

aspect CustomerOrderUtilitiesDataRetentionManagerAspect {
    isBlocked :  Boolean default false; // Set to True if data subject residence period is over
    maxDeletionDate: DateTime;  // date when retention period of data subject expires
    endOfBusinessDate: DateTime; // closed date or the date of payment, also considered as reference date from which residence & retention period is calculated 
}

/* --------------------------------------------------------------- */
/* Extensions                                                      */
/* --------------------------------------------------------------- */

extend CustomerOrder with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderItem with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderNote with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderPriceComponent with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderItemSalesAspect with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend SalesOrderScheduleLine with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderItemServiceAspect with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend ServiceOrderItemReferenceObject with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderPartner with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend SalesDocumentAddress with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderPartnerInternalRef with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderSalesAspect with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderServiceAspect with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend ServiceOrderReferenceObject with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderItemUtilitiesAspect with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderItemUtilitiesReferenceObjectAspect with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderItemUtilitiesSubsequentDocumentAspect with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend CustomerOrderItemUtilitiesSubscriptionAspect with CustomerOrderUtilitiesDataRetentionManagerAspect;
extend PersonAddressDetails with CustomerOrderUtilitiesDataRetentionManagerAspect;

/* --------------------------------------------------------------- */
/* Views                                                           */
/* --------------------------------------------------------------- */

/**
 * View to extend CustomerOrder with businessPartnerId required by the DataRetentionManagerService
 */
view CustomerOrderWithPartner as
    select from CustomerOrder {
        *,
        /**
         * ID of a customer order business partner.
         */
        partners.businessPartnerId as businessPartnerId
    };
