namespace sap.odm.common;

using {sap.odm.common.codeList} from '.';

/**
 * A coded representation of a non-monetary unit of
 * measurement. A unit of measurement is a quantity that is
 * either defined by a standard or established by conventions
 * as a particular type of unit. This unit quantity is the
 * standard of comparison for determining and specifying other
 * quantities of the same type.
 *
 * The codes follow UN/CEFACT Recommendation N°. 20 "Codes for
 * Units of Measure Used in International Trade"
 *
 * For backward compatibility reasons and practical usage also
 *
 * the codes from UN/CEFACT Recommendation N°. 21 are included.
 * "Codes for Passengers, Types of Cargo, Packages and
 * Packaging Materials" As described in the standard documents
 * of Rec. N°. 20, these codes are prefixed by an "X" - which
 * is a full standard compliant notation.
 */
@odm.doc.relatedGDT           : 'UnitOfMeasureCode'
@odm.doc.SAPDelivered         : true
@odm.doc.extensible           : false
@odm.doc.externalStandardLink : 'http://tfig.unece.org/contents/recommendation-20.htm; UN/CEFACT Recommendation #20 (values: Annex I)'
entity UnitOfMeasureCodes : codeList {
      /**
       * The code of the unit.
       */
  key code : String(3);
}

/**
 * A specific unit of measure.
 */
type UnitOfMeasureCode : Association to one UnitOfMeasureCodes;
