namespace sap.odm.common.address;

using {sap.odm.common.address.FormOfAddressCode} from '@sap/odm/dist/common/address/FormOfAddressCodes';
using {sap.odm.common.address.AcademicTitleCode} from '@sap/odm/dist/common/address/AcademicTitleCodes';
using {sap.odm.common.address.FamilyNamePrefixCode} from '@sap/odm/dist/common/address/FamilyNamePrefixCodes';
using {sap.odm.common.address.FamilyNameSuffixCode} from '@sap/odm/dist/common/address/FamilyNameSuffixCodes';

/**
 * Details of a workplace address. The specifics of a workplace
 * address is that it contains a combination of an organization
 * address to ensure postal delivery to the organization
 * reception and an internal address of an employee (including
 * some personal details) inside the organization.
 */
type WorkplaceAddressDetails {
  /**
   * post dispatching info inside the company.
   */
  inhouseMail             : String(10);
  /**
   * additional qualifier for dispatching posts.
   */
  correspondenceShortName : String(10);
  /**
   * company-internal identification of a building, e.g., WDF01.
   */
  building                : String(10);
}

/**
 * Details of a persons role within an organization.
 */
type PersonOrganizationalDetails {
  /**
   * The title of the person in the organization (e.g., VP
   * Sales).
   */
  functionalTitle : String(256);
  /**
   * Name of the department a person works in.
   */
  departmentName  : String(90);
}
