/*
 * @Definition: DMA-aligned CDS-based model of master data addresses (person address, organization address, workplace address)
 * ------------------------------------------------------------------
 *
 * @Owning Area: S4 MDM
 * @Alignment: SAP S/4HANA, SAP SuccessFactors, SAP MDG, SAP DMA
 * @External standard: The domain language is (mostly) consistent with ISO 19160-4:2017
 *
*/
namespace sap.odm.common.address;

using {sap.odm.common.ScriptedObject} from './..';

using {
  sap.odm.common.address.WorkplaceAddressDetails,
  sap.odm.common.address.PersonOrganizationalDetails
} from './AddressDetailTypes';

using {
  sap.odm.common.address.PersonAddressDetails,
  sap.odm.common.address.OrganizationAddressDetails,
} from '@sap/odm/dist/common/address/AddressDetailTypes';

using {
  sap.odm.common.address.PersonAddress,
  sap.odm.common.address.OrganizationAddress,
} from '@sap/odm/dist/common/address/AddressTypes';

using {
  sap.odm.common.address.PhysicalDeliveryAddress,
  sap.odm.common.address.PostalAddress
} from '@sap/odm/dist/common/address/PostalAddressTypes';

/**
 * Scripted physical delivery address describes a destination
 * for a postal delivery to a physical address. A scripted
 * representation after a subset of ISO 15924 (e.g. for Japan:
 * kana, kanji, latin). Text fields of PostalAddress should be
 * encoded using the selected unicode script.
 */
/**
 * Scripted physical delivery address describes a destination
 * for a postal delivery to a physical address. A scripted
 * representation after a subset of ISO 15924 (e.g. for Japan:
 * kana, kanji, latin). Text fields of PostalAddress should be
 * encoded using the selected unicode script.
 */
type ScriptedPhysicalDeliveryAddress : ScriptedObject, PhysicalDeliveryAddress {}
/**
 * Scripted postal address w/o specification of a recipient
 * (org or person). A scripted representation after a subset of
 * ISO 15924 (e.g. for Japan: kana, kanji, latin). Text fields
 * of PostalAddress should be encoded using the selected
 * unicode script.
 */
type ScriptedPostalAddress : ScriptedObject, PostalAddress {}
/**
 * Scripted address of organization. A scripted representation
 * after a subset of ISO 15924 (e.g. for Japan: kana, kanji,
 * latin). Text fields of PostalAddress and
 * OrganizationAddressDetails should be encoded using the
 * selected unicode script.
 */
type ScriptedOrganizationAddress : ScriptedObject, OrganizationAddress {}
/**
 * Scripted address of a person. A scripted representation
 * after a subset of ISO 15924 (e.g. for Japan: kana, kanji,
 * latin). Text fields of PostalAddress and
 * PersonAddressDetails should be encoded using the selected
 * unicode script.
 */
type ScriptedPersonAddress : ScriptedObject, PersonAddress {}
/**
 * Scripted address of a workplace. A scripted representation
 * after a subset of ISO 15924 (e.g. for Japan: kana, kanji,
 * latin). Text fields of PostalAddress and
 * WorkplaceAddressDetails should be encoded using the selected
 * unicode script.
 */
type ScriptedWorkplaceAddress : ScriptedObject, OrganizationAddressDetails, WorkplaceAddressDetails, PostalAddress {}
/**
 * Scripted address of a person at its workplace. A scripted
 * representation after a subset of ISO 15924 (e.g. for Japan:
 * kana, kanji, latin). Text fields of PostalAddress and
 * WorkplaceAddressDetails should be encoded using the selected
 * unicode script.
 */
type ScriptedPersonWorkplaceAddress : ScriptedObject, OrganizationAddressDetails, PersonAddressDetails, PersonOrganizationalDetails, WorkplaceAddressDetails, PostalAddress {}
