namespace sap.odm.orgunit;

using {
  sap.odm.common.CountryCode,
  sap.odm.common.CurrencyCode,
  sap.odm.common.LanguageCode,
  sap.odm.common.cuid,
  sap.odm.common.address.ScriptedOrganizationAddress,
} from '../common';

using {
  sap.odm.orgunit.CompanyCodeId
} from '@sap/odm/dist/orgunit/CompanyCode';

/**
 * Aligned on 2020-12-15: Only necessary attributes are considered.
 */

/**
 * Smallest organizational unit in financial accounting for
 * which individual financial statements for external reporting
 * are drawn, such as balance sheets, profit and loss accounts.
 */
@odm.doc.alternateTerms : ['Company Code']
@odm.doc.relatedGDT     : 'BUKRS'
@ODM.root               : true
entity CompanyCode : cuid {
  /**
   * Human-readable identifier of the company code.
   */
  displayId         : CompanyCodeId;
  /**
   * Name of the company code.
   */
  name              : String(25);
  /**
   * Company of the company code.
   */
  company           : CompanyId;
  /**
   * Boolean indicating whether this Company Code is the main for
   * the Company. If true, this company code provides the
   * essential attributes for the company.
   */
  isMainForCompany  : Boolean;
  /**
   * Country the company code is legally based in.
   */
  country           : CountryCode;
  /**
   * Language for the company code.
   */
  language          : LanguageCode;
  /**
   * Currency in which financial statements are reported.
   */
  currency          : CurrencyCode;
  /**
   * The VAT Registration number of the company code.
   */
  vatRegistrationId : String(20);
}

/**
 * Human-readable identifier of the company.
 */
type CompanyId : String(4);


