namespace sap.odm.product;

using {
      sap.odm.common.cuid,
      sap.odm.common.UnitOfMeasureCode
} from '../common';

using {
      sap.odm.product.ProductId,
      sap.odm.product.sales.ProductSalesAspect
} from '.';

/**
 * Aligned on 2020-12-15: Only necessary attributes are considered.
 */

/**
 * A product is a tangible good, e.g. material or article, or
 * an intangible good, e.g. services, digital goods, that is
 * part of the business activity of a company. A product is
 * used along the value chain and contributes directly or
 * indirectly to the added value. It does not extend to
 * instance level, such as individual materials stocked as
 * physical inventory, meaning that individual objects and
 * serialized materials are not part of the product domain. It
 * also does not extend to subsets of a material, e.g. batches.
 */
@odm.doc.alternateTerms : ['Material']
@odm.doc.relatedGDT     : 'Product'
@ODM.root               : true
entity Product : cuid, /*S4Product,S4ServicePartsManagement*/ {
      /**
       * Product number.
       */
      displayId                        : ProductId not null;
      /**
       * Product name.
       */
      /*
       * Name length is set to 255 based on CX FSM (Field Service Management) feedback,
       * however S/4 is limited to 40 chars.
       */
      name                             : localized String(255);
      /**
       * Sales attributes describing a product.
       */
      salesAspect                      : Composition of one ProductSalesAspect;
}
