namespace sap.odm.businesspartner.s4;

using { sap.odm.businesspartner.s4.MaritalStatusCode } from './MaritalStatusCodes.cds';
using { sap.odm.common.CountryCode } from '../../common/CountryCodes.cds';
using { sap.odm.common.Validity } from '../../common/Validity.cds';

/**
 * Name details of a person.
 */
aspect PersonName {
  /**
   * PO Box address without PO Box number flag.
   */
  birthName: String(40);
  /**
   * Nickname of Business Partner (Person).
   */
  nickName: String(40);
  /**
   * Marital Status of Business Partner.
   */
  maritalStatus: MaritalStatusCode;
  /**
   * Name of Employer of a Natural Person.
   */
  naturalPersonEmployerName: String(35);
  /**
   * Occupation group.
   */
  businessPartnerOccupationGroup: String(4);
  /**
   * Birthplace of business partner.
   */
  businessPartnerBirthplaceName: String(40);
  /**
   * Date of death of business partner.
   */
  businessPartnerDeathDate: Date;
  /**
   * The name format rule country and the name format rule key
   * together uniquely identify a formatting rule.
   */
  nameCountry: CountryCode;
  /**
   * The name format specifies the sequence in which name
   * components are assembled to present the name of a person in
   * a complete form.
   */
  nameFormat: String(2);
};

/**
 * Data for communication with the business partner.
 */
aspect AddressData {
  /**
   * Indicator for address independent.
   */
  isIndependent: Boolean;
};

/**
 * Abstract entity for communication channel that can be set to
 * default.
 */
aspect DefaultableCommunicationChannel: Validity  {
  /**
   * Usage Denied Indicator.
   */
  usageDeniedIndicator: Boolean;
};

/**
 * Communication channel type phone.
 */
aspect Phone {
  /**
   * "SMS" Enabled Indicator.
   */
  smsEnabledIndicator: Boolean;
};

/**
 * Communication channel type website.
 */
aspect Website: Validity  {
  /**
   * URI type flag.
   */
  uriType: String(3);
};
