namespace sap.odm.common;

using { sap.odm.common.codeList } from './aspects.cds';

/**
 * Commonly used trading terms that comply with the standards
 * established by the International Chamber of Commerce (ICC).
 * Incoterms specify internationally recognized procedures that
 * the shipper and the receiving party must follow for the
 * shipping transaction to be completed successfully.If goods
 * are shipped through a port of departure, the appropriate
 * Incoterm might be: FOB (“Free On Board”). You can provide
 * further details (for example, the name of the port) in the
 * secondary Incoterm field: FOB Boston, for example.
 */
type IncotermsClassificationCode: association to one IncotermsClassificationCodes;

/**
 * Commonly used trading terms that comply with the standards
 * established by the International Chamber of Commerce (ICC).
 * Incoterms specify internationally recognized procedures that
 * the shipper and the receiving party must follow for the
 * shipping transaction to be completed successfully.If goods
 * are shipped through a port of departure, the appropriate
 * Incoterm might be: FOB (“Free On Board”). You can provide
 * further details (for example, the name of the port) in the
 * secondary Incoterm field: FOB Boston, for example. The codes
 * are also freely available as UN/CEFACT recommendation. The
 * list here is an superset from UN/CEFACT 2011, older codes
 * (DAF,DDU,DEQ,DES) which are removed in 2010 and some SAP
 * extensions.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: true
@odm.doc.relatedGDT: 'IncotermsClassificationCode'
entity IncotermsClassificationCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(3);
};
