namespace sap.odm.common.address;

using { sap.odm.common.address.FormOfAddressCode } from './FormOfAddressCodes.cds';
using { sap.odm.common.address.AcademicTitleCode } from './AcademicTitleCodes.cds';
using { sap.odm.common.address.FamilyNamePrefixCode } from './FamilyNamePrefixCodes.cds';
using { sap.odm.common.address.FamilyNameSuffixCode } from './FamilyNameSuffixCodes.cds';

/**
 * Details of a person.
 */
type PersonAddressDetails: {
  /**
   * Persons given name / first name.
   */
  firstName: String(128);
  /**
   * Persons middle name (optional).
   */
  middleName: String(128);
  /**
   * Person surname.
   */
  lastName: String(128);
  /**
   * e.g. Father´s name (Spain: Aranxta Sanchez y Vicario,
   * Vicario is Father´s name; similar concept for Russia).
   */
  secondLastName: String(128);
  /**
   * Abbreviation of the person''s name, mostly first letters of
   * first and last name.
   */
  initials: String(128);
  /**
   * Specifies how to address the person(s), e.g., Mr., Mrs., Mr.
   * and Mrs., etc.
   */
  formOfAddress: FormOfAddressCode;
  /**
   * Code of the academic title as defined in the code list.
   */
  academicTitle: AcademicTitleCode;
  /**
   * Additional title for cases like Prof. Dr. Dr. XYZ.
   */
  additionalAcademicTitle: AcademicTitleCode;
  /**
   * Prefix words for the name of a person, for example "Van
   * der".
   */
  namePrefix: FamilyNamePrefixCode;
  /**
   * Additional Prefixes, if needed.
   */
  additionalNamePrefix: FamilyNamePrefixCode;
  /**
   * Suffix words for the family name, e.g., junior, senior, III,
   * Ph.D., etc.
   */
  nameSuffix: FamilyNameSuffixCode;
  /**
   * Full formatted person name by concatenating all fields. Used
   * in some cases to transfer separate text.
   */
  formattedPersonName: String(4000);
};

/**
 * Printable format of 4 lines of organization name, manually
 * entered for proper formatting. At least ...Line1 must be filled.
 * 
 * If needed, a writer can _in addition_ write the long string formattedOrgName.
 */
type OrganizationAddressDetails: {
  /**
   * Formatted organizational name line 1.
   */
  formattedOrgNameLine1: String(40);
  /**
   * Formatted organizational name line 2.
   */
  formattedOrgNameLine2: String(40);
  /**
   * Formatted organizational name line 3.
   */
  formattedOrgNameLine3: String(40);
  /**
   * Formatted organizational name line 4.
   */
  formattedOrgNameLine4: String(40);
  /**
   * Fully formatted organization name.
   */
  formattedOrgName: String(512);
};
