namespace sap.odm.common.address;

using { sap.odm.common.codeList } from '../aspects.cds';

/**
 * A specific country subdivision code.
 */
type CountrySubdivisionCode: association to one CountrySubdivisionCodes;

/**
 * Represents the name of a principal subdivision (e.g province
 * or state) of countries coded in ISO 3166-1. This code is
 * based on the two-letter code element from ISO 3166-1
 * followed by a separator and up to three alphanumeric
 * characters (published as ISO 3166-2).
 * 
 * The characters after the separator cannot be used on their
 * own, they must be preceded by the alpha-2 country code. The
 * codes denoting the subdivision are usually obtained from
 * national sources and stem from coding systems already in
 * place in the country. For example: ID-RI is the Riau
 * province of Indonesia, TG-C is the Central region in Togo,
 * AQ is Antarctica and CR-201 is the Benešov District within
 * Central Bohemian Region of the Czech Republic.
 * 
 * The codes here are for practical reasons and legal
 * requirements based on standard which deviates from ISO. The
 * values are based on ERP table "T005S" values, published and
 * maintained by SAP in SAP Note 1164216: <https://launchpad.support.sap.com/#/notes/1164216>.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
@odm.doc.externalStandardLink: 'https://launchpad.support.sap.com/#/notes/1164216'
@odm.doc.relatedGDT: 'RegionCode, NielsenRegionCode, JurisdictionSubdivisionCode'
entity CountrySubdivisionCodes: codeList  {
  /**
   * Country subdivision code.
   */
  key code: String(6);
};
