namespace sap.odm.common.address;

using { sap.odm.common.codeList } from '../aspects.cds';

/**
 * A specific secondary region code.
 */
type SecondaryRegionCode: association to one SecondaryRegionCodes;

/**
 * A specific tertiary region code.
 */
type TertiaryRegionCode: association to one TertiaryRegionCodes;

/**
 * Helper Type to keep consistent length of region codes across
 * code lists.
 */
type RegionCode: String(8);

/**
 * Region codes may be derived from ISO 3166-2 codelist
 * (subdivisions) or provided by local authorities. No
 * assumptions about the length of the code. Code list with
 * codes that are defined by local authorities.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: true
entity SecondaryRegionCodes: codeList  {
  /**
   * Secondary region code.
   */
  key code: RegionCode;
};

/**
 * Region codes may be derived from ISO 3166-2 codelist
 * (subdivisions) or provided by local authorities. No
 * assumptions about the length of the code. Code list with
 * codes that are defined by local authorities.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: true
entity TertiaryRegionCodes: codeList  {
  /**
   * Tertiary region code.
   */
  key code: RegionCode;
};
