namespace sap.odm.common.address;

using { sap.odm.common.codeList } from '../aspects.cds';

/**
 * A specific street code.
 */
type StreetCode: association to one StreetCodes;

/**
 * StreetCodes are an alias (aiming for better readability and
 * understandability) for Thoroughfare codes, which are defined
 * by ISO 19160-4:2017 as an abstraction over street, road,
 * square, and the like. Thoroughfare codes may be regulated
 * locally, optional otherwise. identifies the road or part of
 * a road or other access route along which a delivery point
 * can be accessed, either directly or via a secondary or
 * tertiary road or access route. For addressing purposes, a
 * thoroughfare need not be on land, e.g. a canal or river
 * might serve as a thoroughfare in the address of a houseboat
 * or of a construction on the bank. A thoroughfare is a road
 * or way connecting one location to another. On land a
 * thoroughfare may refer to any type of road.
 */
@odm.doc.SAPDelivered: false
@odm.doc.alternateTerms: [ 'Thoroughfare code' ]
@odm.doc.extensible: true
@odm.doc.externalStandardLink: 'ISO 19160-4:2017 / UPU standard'
entity StreetCodes: codeList  {
  /**
   * Street code.
   */
  key code: String(10);
};
