namespace sap.odm.common.address;

using { sap.odm.common.codeList } from '../aspects.cds';

/**
 * A specific town code.
 */
type TownCode: association to one TownCodes;

/**
 * Town is an abstraction defined in ISO 19160-4:2017 for
 * cities, towns, villages, etc. Town codes are regulated
 * locally for some countries (Qatar, Peru, Oman, Italy tax
 * codes), otherwise just omitted. This defines a codelist for
 * towns or just a name if a code is missing. Element
 * indicating the name of the populated place in which a
 * delivery point is located or near to or via which the
 * delivery point is accessed.
 */
@odm.doc.SAPDelivered: false
@odm.doc.extensible: true
@odm.doc.externalStandardLink: 'ISO 19160-4:2017'
entity TownCodes: codeList  {
  /**
   * Town code.
   */
  key code: String(10);
};
