namespace sap.odm.common.address.s4;

using { sap.odm.common.address.PostalCode } from '../PostalAddressTypes.cds';

/**
 * Postal address describes a destination for a postal
 * delivery. It may be either a physical address or a service
 * point address (e.g. PO box). The types are described in a
 * codelist "DeliveryServiceEnum".
 */
aspect PostalAddress {
  /**
   * Post Box address without Post Box number flag.
   */
  postBoxIsWithoutNumber: Boolean;
  /**
   * Postal code that is assigned directly to one company (=
   * company postal code = major customer postal code).
   */
  companyPostalCode: PostalCode;
  /**
   * The delivery service is part of the PO box address.
   */
  deliveryServiceNumber: String(10);
  /**
   * City or District supplement.
   */
  additionalCityName: String(40);
};
