namespace sap.odm.common;

/**
 * Aspect to capture changes by user and name.
 */
aspect managed {
  /**
   * Timestamp of last modification.
   */
  @readonly: true
  @title: 'Changed at'
  modifiedAt: DateTime;
  /**
   * Timestamp of creation.
   */
  @readonly: true
  @title: 'Created at'
  createdAt: DateTime;
};

/**
 * Base aspects to define code list entities.
 */
@ODM.codeList: true
aspect codeList {
  /**
   * User-facing name of a code list entry.
   */
  @title: 'Name'
  name: localized String(255);
  /**
   * Description of a code list entry.
   */
  @title: 'Description'
  descr: localized String(1000);
};

/**
 * Aspect for entities with canonical universal IDs.
 */
aspect cuid {
  /**
   * Entity identifier based on Universally Unique Identifier.
   */
  key id: UUID;
};

/**
 * Enumeration containing values for indication the type of
 * change.
 */
type LicensedCodeListChangeTypeEnum: String(1) enum {
  unchanged = 'n';
  changedBySap = 's';
  changedByUser = 'u';
  deletedBySap = 'd';
  deletedByUser = 'x';
} ;

/**
 * Base aspects to define licensed code list entities (e.g.
 * ISO/DIN copyrighted code lists).
 */
aspect licensedCodeList: codeList  {
  /**
   * This field allows to identify changed values of the list,
   * and indicates the type of change.
   */
  @title: 'Change Type'
  changeType: LicensedCodeListChangeTypeEnum not null default 'n';
};
