namespace sap.odm.common;

/**
 * Fixed-length String type to avoid overhead due to unbounded, maximum length Strings.
 */
type ShortString: String(255);

/**
 * Generic URI type based on String.
 */
type URI: String(2048);

/**
 * Generic URL type based on String.
 */
type URL: URI;

/**
 * GeoCoordinates contain the geographic data, in other words longitude, latitude and altitude specified as per the WGS84 reference system, which enables you to determine a position on the globe. (http://www.unoosa.org/pdf/icg/2012/template/WGS_84.pdf).
 */
type GeoCoordinates: {
  /**
   * Latitude value of the coordinates.
   */
  latitude: Double;
  /**
   * Longitude value of the coordinates.
   */
  longitude: Double;
  /**
   * Altitude value of the coordinates.
   */
  altitude: Double;
};
