namespace sap.odm.dpp;

using {
  sap.odm.dpp.DisplayId,
  sap.odm.dpp.Version
} from './types.cds';
using {
  sap.odm.common.cuid,
  sap.odm.common.managed
} from '../common/aspects.cds';
using { sap.odm.dpp.Purpose2DataController } from './Purpose2DataController.cds';

/**
 * Role of a Data Subject whose personal data processing is
 * legitimated by the purpose that is represented by master
 * data objects related to purposes.
 */
type DataSubjectRole: {
  /**
   * Human-readable identifier of the Data Subject Role.
   */
  displayId: DisplayId not null;
  /**
   * Title of the Data Subject Role is a short description used
   * for display.
   */
  name: localized String(60);
};

/**
 * Justifying reason for processing of personal data.
 */
@ODM.root: true
entity Purpose: cuid, managed  {
  /**
   * Version of the purpose, major changes to the purpose
   * definition over time is tracked by a new version.
   */
  version: Version;
  /**
   * Human-readable identifier of the purpose.
   */
  displayId: DisplayId not null;
  /**
   * Title of the purpose is a short description used for
   * display.
   */
  name: localized String(60);
  /**
   * Role of the Data Subject whose personal data processing is
   * legitimated by the purpose.
   */
  dataSubjectRole: DataSubjectRole;
  /**
   * Group of Data Controllers that are responsible for the
   * processing of personal data of a Data Subject.
   */
  dataControllers: association to many Purpose2DataController on dataControllers.purpose = $self;
};
