namespace sap.odm.finance.payment;

using { sap.odm.common.CountryCode } from '../../common/CountryCodes.cds';
using { sap.odm.common.CurrencyCode } from '../../common/CurrencyCodes.cds';

/**
 * The base type for details of a payment.
 */
type PaymentDetailsBaseType: {
  /**
   * Country of the bank.
   */
  bankCountry: CountryCode;
  /**
   * Name of the bank account holder.
   */
  bankAccountHolderName: String(256);
  /**
   * IBAN of the bank details.
   */
  IBAN: String(34);
  /**
   * Old bank account number.
   */
  bankAccount: String(35);
  /**
   * The bank number or bank code.
   */
  bankNumber: String(15);
  /**
   * Reference details of the bank account.
   */
  bankAccountReference: String(20);
  /**
   * Bank account currency.
   */
  bankAccountCurrency: CurrencyCode;
  /**
   * Bank Transfer purpose.
   */
  additionalPaymentReference: String(40);
  /**
   * Alternate account like e-mail.
   */
  alternatePaymentAccount: String(256);
};
