namespace sap.odm.procurement.s4;

using { sap.odm.procurement.s4.TaxGroupCode } from './TaxGroupCodes.cds';
using { sap.odm.procurement.s4.MinorityIndicatorsCode } from './MinorityIndicatorsCodes.cds';
using { sap.odm.procurement.s4.VendorRecipientTypeCode } from './VendorRecipientTypeCodes.cds';

/**
 * Entity which holds Supplier related information of a
 * BusinessPartner entity.
 */
aspect SupplierInformation {
  /**
   * Determines whether the company is liable to value-added tax
   * (VAT).
   */
  vatLiability: Boolean;
  /**
   * Indicates that all data in the master record will be deleted
   * for the specified sales area. Before the deletion is made,
   * the system checks for dependent data that would prevent the
   * deletion.
   */
  deletionIndicator: Boolean;
  /**
   * Classification of companies according to tax aspects.
   */
  responsibleType: TaxGroupCode;
};

aspect SupplierAccountingInformation {
  /**
   * General Ledger Account Number.
   */
  reconciliationAccountNumber: String(10);
  /**
   * Minority Indicator.
   */
  minorityGroup: MinorityIndicatorsCode;
  /**
   * When incoming invoices are entered or when memos are entered
   * in Financial Accounting, the system checks whether an
   * invoice or credit memo has already been entered for the same
   * date.
   */
  isDoubleInvoice: Boolean;
  /**
   * All bank data is determined using this key.
   */
  houseBank: String(5);
  /**
   * In cash management, customers and suppliers are allocated to
   * planning groups by means of an entry made in the master
   * record.
   */
  cashPlanningGroup: String(10);
  /**
   * Internet address of partner company clerk.
   */
  accountingClerkInternetAddress: String(130);
};

/**
 * Taxed which are withhold from tax authorities.
 */
aspect SupplierAccountingWithholdingTax {
  /**
   * The type of recipient can be defined in the vendor master
   * record.
   */
  recipientType: VendorRecipientTypeCode;
};

/**
 * Business terms for a supplier associated to a certain
 * purchasing organization.
 */
aspect SupplierPurchasingArrangement {
  /**
   * Purchasing group unique ID.
   */
  purchasingGroupDisplayId: String(3);
};

/**
 * Business process related functions of the purchasing
 * arrangement.
 */
aspect SupplierPurchasingArrangementFunction {
  /**
   * Supplier description of partner (plant, storage location).
   */
  partnerDescription: String(30);
  /**
   * Identifier of the corresponding partner based on Partner
   * type.
   */
  partnerNumber: String(10);
};
