namespace sap.odm.workforce.common;

using { sap.odm.common.codeList } from '../../common/aspects.cds';

/**
 * A specific address usage.
 */
type AddressUsageCode: association to one AddressUsageCodes;

/**
 * A specific email usage.
 */
type EmailUsageCode: association to one EmailUsageCodes;

/**
 * A specific phone usage.
 */
type PhoneUsageCode: association to one PhoneUsageCodes;

/**
 * A specific job detail status.
 */
type JobDetailStatusCode: association to one JobDetailStatusCodes;

/**
 * A specific event.
 */
type EventCode: association to one EventCodes;

/**
 * A specific event reason.
 */
type EventReasonCode: association to one EventReasonCodes;

/**
 * A specific employee class code.
 */
type EmployeeClassCode: association to one EmployeeClassCodes;

/**
 * A specific payment type.
 */
type PaymentTypeCode: association to one PaymentTypeCodes;

/**
 * A specific payment method.
 */
type PaymentMethodCode: association to one PaymentMethodCodes;

/**
 * A specific bank account type.
 */
type BankAccountTypeCode: association to one BankAccountTypeCodes;

/**
 * A specific bank control key.
 */
type BankControlKeyCode: association to one BankControlKeyCodes;

/**
 * A specific photo type.
 */
type WorkforcePersonPhotoTypeCode: association to one WorkforcePersonPhotoTypeCodes;

/**
 * List of possible address usages.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity AddressUsageCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible bank account types.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity BankAccountTypeCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(20);
};

/**
 * List of possible bank control keys.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity BankControlKeyCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(2);
};

/**
 * List of possible email usages.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity EmailUsageCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible employee class codes.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: true
entity EmployeeClassCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible events.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity EventCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible event reasons.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity EventReasonCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible job detail states.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity JobDetailStatusCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible payment methods.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity PaymentMethodCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible payment types.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity PaymentTypeCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible phone usages.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity PhoneUsageCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};

/**
 * List of possible photo types.
 */
@odm.doc.SAPDelivered: true
@odm.doc.extensible: false
entity WorkforcePersonPhotoTypeCodes: codeList  {
  /**
   * Code list entry.
   */
  key code: String(255);
};
