namespace sap.odm.workforce.foundation;

using { sap.odm.common.cuid } from '../../common/aspects.cds';

/**
 * The attributes of Job Classification that must be tracked in
 * time.
 */
aspect JobClassificationDetails {
  /**
   * Job Description.
   */
  description: localized String(4000);
  /**
   * Job Name.
   */
  name: localized String(90);
  /**
   * Status of the Job Classification, is it active or inactive?
   */
  isActive: Boolean;
  /**
   * A Job Classification can have one super Job Classification.
   */
  superOrdinateJobClassification: association to one JobClassification;
};

/**
 * To classify a Job and assign it to a Job code.
 */
@ODM.root: true
entity JobClassification: cuid  {
  /**
   * Job externalId.
   */
  externalId: String(128);
  /**
   * All temporal attributes of the job classification.
   */
  @odm.temporalDate: true
  details: composition of one JobClassificationDetails;
};
