namespace sap.odm.workforce.foundation;

using { sap.odm.finance.costobject.CostCenter } from '../../finance/costobject/CostCenter.cds';
using {
  sap.odm.common.cuid,
  sap.odm.common.managed
} from '../../common/aspects.cds';
using { sap.odm.workforce.foundation.OrganizationalUnitCategoryCode } from './OrganizationalUnitCategoryCodes.cds';

/**
 * The attributes of OrganizationalUnit that must be tracked in
 * time.
 */
aspect OrganizationalUnitDetails {
  /**
   * The name of the Organizational Unit.
   */
  name: localized String(128);
  /**
   * A further description of the Organizational Unit.
   */
  description: localized String(256);
  /**
   * The cost center related to this Organizational Unit if any.
   */
  costCenter: association to one CostCenter;
  /**
   * Status of the Organizational Unit, is it active or inactive?
   */
  isActive: Boolean;
};

/**
 * This is used for creating an array of relationships to super
 * ordinate organizational units. Thus, a child organizational
 * unit can refer to multiple super ordinate organizational
 * units. The super ordinate organizational units don't refer
 * back to the sub ordinate organizational units. These arrays
 * are overlapping in time slices.
 */
aspect SuperOrdinateOrganizationalUnit {
  /**
   * Reference to one super ordinate organizational unit.
   */
  key superOrdinateOrgUnit: association to one OrganizationalUnit;
};

/**
 * The Organizational Unit in the domain human resources is the
 * organizational unit where people work.
 */
@ODM.root: true
entity OrganizationalUnit: cuid, managed  {
  /**
   * Identifier in SuccessFactors.
   */
  externalId: String(128);
  /**
   * The category of this Organizational Unit, typically one of
   * department, division, business unit.
   */
  category: OrganizationalUnitCategoryCode;
  /**
   * All temporal attributes of the organizational unit.
   */
  @odm.temporalDate: true
  details: composition of one OrganizationalUnitDetails;
  /**
   * An Organizational Unit can have multiple super
   * Organizational Units (i.e., parents) in the hierarchy.
   */
  @odm.temporalDate: true
  superOrdinateOrgUnits: composition of many SuperOrdinateOrganizationalUnit;
};
