
using {sap.beta.odm.utilities.billingaccount as ba} from '../../../../db/models/beta/odm/billingaccount';

/**
 * Service definition
 */
service API_BILLING_ACCOUNT @(path: '/api/beta/ba', requires: 'authenticated-user') {
    @(restrict: [
        { grant: ['WRITE'], to: 'API.Write'},
        { grant: ['READ'], to: 'API.Read'}
        ],
    Capabilities: { DeleteRestrictions.Deletable: false }
    )
    
    entity BillingAccount as projection on ba.BillingAccount {
        id, 
        displayId, 
        businessPartner, 
        category, 
        billingAccountRelationship, 
        toleranceGroup, 
        clearingCategory, 
        accountDeterminationCode, 
        paymentTerms, 
        contractAccountName, 
        companyCodeGroup, 
        companyCode, 
        incomingPaymentMethod, 
        outgoingPaymentMethod, 
        incomingPaymentBankAccountId, 
        outgoingPaymentBankAccountId, 
        incomingPaymentPaymentCard, 
        outgoingPaymentPaymentCard, 
        country, 
        accountAddressId, 
        alternativePayee, 
        alternativePayer, 
        dunningProcedure,
        alternativeBillingAccount
    };

    /**
     * Entities for codelists
     */
    @(restrict: [
        { grant: ['WRITE'], to: 'API.Write'},
        { grant: ['READ'], to: 'API.Read'
        }
    ])
    entity CategoryCodes as projection on ba.CategoryCodes;

    @(restrict: [
        { grant : ['WRITE'], to: 'API.Write'},
        { grant : ['READ'], to: 'API.Read'}
    ])
    entity BillingAccountRelationshipCodes as projection on ba.BillingAccountRelationshipCodes;

    @(restrict: [
        { grant: ['WRITE'], to: 'API.Write'},
        { grant: ['READ'], to: 'API.Read'}
    ])
    entity ClearingCategoryCodes as projection on ba.ClearingCategoryCodes;

    @(restrict: [
        { grant: ['WRITE'], to: 'API.Write'},
        { grant: ['READ'], to: 'API.Read'}
    ])
    entity ToleranceGroupCodes as projection on ba.ToleranceGroupCodes;

    @(restrict: [
        { grant: ['WRITE'], to: 'API.Write'},
        { grant: ['READ'], to: 'API.Read'}
    ])
    entity AccountDeterminationIdCodes as projection on ba.AccountDeterminationIdCodes;

    /**
     * Templates for Billing accounts
     */
    @(restrict: [
        { grant: ['WRITE'], to: 'API.Write'},
        { grant: ['READ'], to: 'API.Read'}
    ])
    entity BillingAccountTemplates as projection on ba.BillingAccountTemplates {
        templateId, 
        fieldName, 
        fieldValue,
        sapProvided
    };
}