using {
    sap.odm.common as common,
    sap.odm.finance as finance,
    sap.odm.sales as sales,
    sap.beta.c4u.foundation.retailer.serviceprovider as serviceprovider,
    sap.odm.businesspartner as businesspartner,
} from '../../../../db';

service BusinessPartnerService @(path: '/api/beta/bp', requires: 'authenticated-user') { 
    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read', where: 'isBlocked = false' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartner as projection on businesspartner.BusinessPartner {
        id,
        displayId,
        businessPartnerType @(assert.range: true),
        person,                         // composition of one PersonDetails
        organization,                   // composition of one OrganizationDetails
        isBlocked,
        bankAccounts,                   // composition of many BankAccount
        taxNumbers,
        addressData,                    // composition of many AddressData
        roles,                          // composition of many BusinessPartnerRole
        serviceProviderInformation
    }

    @(restrict: [
        { grant: ['READ'], to: 'API.Read', where: 'isBlocked = false' }
        ],
        cds.redirection.target: false )
    @readonly entity BusinessPartnerSearch as projection on businesspartner.BusinessPartner {
        id,
        displayId,
        isBlocked,
        person.nameDetails.firstName as firstName,
        person.nameDetails.lastName as lastName,
        addressData.emailAddresses.address as emailAddress
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerPerson as projection on businesspartner.BusinessPartner.person {
        up_,
        nameDetails,            // composition of one PersonName
        gender,                 
        language,
        correspondenceLanguage,
        birthDate,
        nationality
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerPersonNameDetails as projection on businesspartner.BusinessPartner.person.nameDetails {
        up_,
        firstName,
        middleName,
        lastName
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerOrganization as projection on businesspartner.BusinessPartner.organization {
        up_,                    // BusinessPartner
        nameDetails             // composition of OrganizationName
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerOrganizationNameDetails as projection on businesspartner.BusinessPartner.organization.nameDetails {
        up_,                    // BusinessPartnerOrganization
        formattedOrgNameLine1,
        formattedOrgNameLine2
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerBankAccounts as projection on businesspartner.BusinessPartner.bankAccounts {
        up_,                    // BusinessPartner
        id,
        bankAccountName,
        bankControlKey,
        validFrom,
        validTo,
        bankCountry,
        bankAccountHolderName,
        IBAN,
        bankAccount,
        bankNumber,
        bankAccountReference
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerTaxNumbers as projection on businesspartner.BusinessPartner.taxNumbers {
        up_,                     // BusinessPartner
        taxNumberType,
        taxNumber
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerAddressData as projection on businesspartner.BusinessPartner.addressData {
        up_,                        // BusinessPartner
        id,
        usages,                     // composition of many AddressDataUsage
        postalAddressType,
        personPostalAddress,        // composition of one PersonAddress
        organizationPostalAddress,  // composition of one OrganizationAddress
        emailAddresses,              // composition of many Email
        validFrom,
        validTo
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerAddressDataUsages as projection on businesspartner.BusinessPartner.addressData.usages {
        up_,                        // BusinessPartnerAddressData
        usage,
        validTo,
        validFrom,
        isStandard
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerAddressDataPersonPostalAddress as projection on businesspartner.BusinessPartner.addressData.personPostalAddress {
        up_,                            // BusinessPartnerAddressData
        street,                         // type Street
        streetSuffix1,
        streetSuffix2,
        houseNumber,
        town,                           // type Town
        primaryRegion,
        country,
        postCode,
        companyPostalCode
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerAddressDataOrganizationPostalAddress as projection on businesspartner.BusinessPartner.addressData.organizationPostalAddress {
        up_,                            // BusinessPartnerAddressData
        street,                         // type Street
        streetSuffix1,
        streetSuffix2,
        houseNumber,
        town,                           // type Town
        primaryRegion,
        country,
        postCode,
        companyPostalCode
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerAddressDataEmailAddresses as projection on businesspartner.BusinessPartner.addressData.emailAddresses {
        up_,                        // BusinessPartnerAddressData
        id,
        address
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerRoles as projection on businesspartner.BusinessPartner.roles {
        up_,            // BusinessPartner
        role,
        validFrom,
        validTo
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read'} ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerServiceProviderInformation as projection on businesspartner.BusinessPartner.serviceProviderInformation {
        up_,            // ServiceProviderDetails
        id,
        marketFunction,
        marketFunctionCodeNumber1,
        marketFunctionSource1,
        marketFunctionCodeNumber2,
        marketFunctionSource2,
        validFrom,
        validTo,
    }

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity TaxNumberTypeCodes as projection on businesspartner.TaxNumberTypeCodes;

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity AddressDataUsageCodes as projection on businesspartner.AddressDataUsageCodes;

        @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity BusinessPartnerRoleCodes as projection on businesspartner.BusinessPartnerRoleCodes;

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity GenderCodes as projection on common.GenderCodes;

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity LanguageCodes as projection on common.LanguageCodes;

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity CountryCodes as projection on common.CountryCodes;

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity CountrySubdivisionCodes as projection on common.address.CountrySubdivisionCodes;

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity StreetCodes as projection on common.address.StreetCodes;

        @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity TownCodes as projection on common.address.TownCodes;

    @(  restrict: [
            { grant: ['WRITE'], to: 'API.Write'},
            { grant: ['READ'], to: 'API.Read' }
        ],
        Capabilities: { DeleteRestrictions.Deletable: false })
    entity MarketFunctionCodes as projection on serviceprovider.MarketFunctionCodes;
}
