using {
    sap.beta.odm.utilities.billingaccount as ba
    } from '../../../db/models/beta/odm/billingaccount';

using API_BUSINESS_PARTNER as bp from '../../external/API_BUSINESS_PARTNER';

/*
 * Expose entities and attributes that have been defined as IsPotentiallyPersonal. Entity naming must match naming of API_BILLING_ACCOUNTS
 */

service BillingAccountPersonalDataManagerService @(path:'/api/beta/ba/dpp/pdm', requires:'authenticated-user'){
    @PersonalData.EntitySemantics: 'DataSubject'
    @(restrict: [{ grant: ['READ'], to: 'PersonalDataManagerUser' }])
    @readonly entity BusinessPartner as select from ba.BillingAccount {
         @PersonalData.FieldSemantics:'DataSubjectID'
         @Common.Label: '{i18n>labelBusinessPartnerId}'
         key businessPartner.id
        };

     @(restrict: [{ grant: ['READ'], to: 'PersonalDataManagerUser' }])
     @readonly entity BillingAccount as select from ba.BillingAccount {
        key id,   
        displayId,
        contractAccountName,
        @Common.Label: '{i18n>labelCountry}'
        country.code as country_code,
        @Common.Label: '{i18n>labelCurrency}'
        country.currency.code as country_currency_code,
        accountAddressId,
        @Common.Label: '{i18n>labelAlternativePayee}'
        alternativePayee.id as alternativePayee_id,
        @Common.Label: '{i18n>labelAlternativePayer}'
        alternativePayer.id as alternativePayer_id,
        @Common.Label: '{i18n>labelAlternativeBillingAccount}'
        alternativeBillingAccount.id as alternativeBillingAccount_id,
        @PersonalData.FieldSemantics:'DataSubjectID'
        @Common.Label: '{i18n>labelBusinessPartnerId}'
        businessPartner.id as businessPartner_id,
    };

};